@@ -1,6 +1,7 @@
 import time
 from typing import Callable
 import cv2
+import numpy as np
 
 
 def _default_draw_fps(fps):
@@ -11,7 +12,7 @@ class FpsDrawer:
     This class is used to draw the frames per secondn(fps) on the screen
     """
     
-    def __init__(self, draw_fps_fn:Callable[[float], str]=_default_draw_fps, org= (7, 70), fontFace=cv2.FONT_HERSHEY_SIMPLEX, fontScale=2, color= (100, 255, 0), thickness=3, lineType=cv2.LINE_AA) -> None:
+    def __init__(self, draw_fps_fn:Callable[[float], str]=_default_draw_fps, org=(7, 70), fontFace=cv2.FONT_HERSHEY_SIMPLEX, fontScale=2, color= (100, 255, 0), thickness=3, lineType=cv2.LINE_AA) -> None:
         
         self.__counter = -1
         self._start = time.perf_counter()
@@ -31,8 +32,7 @@ class FpsDrawer:
     def get_fps(self):
         return self.__counter / (self._end - self._start)    
     
-    def draw(self, image):
-        
+    def draw(self, image:np):
         self._tick()
         cv2.putText(image, self.draw_fps_fn(self.get_fps()), self.org, self.fontFace, self.fontScale, self.color, self.thickness, self.lineType) 
     
